#ifndef UAE_ASSERT_H
#define UAE_ASSERT_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <assert.h>
#define uae_assert assert

#endif /* UAE_ASSERT_H */
